@@ -2,7 +2,7 @@
 #' @export
 assert_all_are_in_closed_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are not all in range.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all in range.", get_name_in_parent(x))
   assert_engine(x, is_in_closed_range, msg, lower = lower, upper = upper)  
 }
 
@@ -10,7 +10,7 @@ assert_all_are_in_closed_range <- function(x, lower = -Inf, upper = Inf)
 #' @export
 assert_any_are_in_closed_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are all out of range.", get_name_in_parent(x))
+  msg <- gettextf("%s are all out of range.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_in_closed_range, 
@@ -25,7 +25,7 @@ assert_any_are_in_closed_range <- function(x, lower = -Inf, upper = Inf)
 #' @export
 assert_all_are_in_left_open_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are not all in range.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all in range.", get_name_in_parent(x))
   assert_engine(x, is_in_left_open_range, msg, lower = lower, upper = upper)  
 }
 
@@ -33,7 +33,7 @@ assert_all_are_in_left_open_range <- function(x, lower = -Inf, upper = Inf)
 #' @export
 assert_any_are_in_left_open_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are all out of range.", get_name_in_parent(x))
+  msg <- gettextf("%s are all out of range.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_in_left_open_range, 
@@ -48,7 +48,7 @@ assert_any_are_in_left_open_range <- function(x, lower = -Inf, upper = Inf)
 #' @export
 assert_all_are_in_open_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are not all in range.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all in range.", get_name_in_parent(x))
   assert_engine(x, is_in_open_range, msg, lower = lower, upper = upper)  
 }
 
@@ -56,7 +56,7 @@ assert_all_are_in_open_range <- function(x, lower = -Inf, upper = Inf)
 #' @export
 assert_any_are_in_open_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are all out of range.", get_name_in_parent(x))
+  msg <- gettextf("%s are all out of range.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_in_open_range, 
@@ -72,7 +72,7 @@ assert_any_are_in_open_range <- function(x, lower = -Inf, upper = Inf)
 assert_all_are_in_range <- function(x, lower = -Inf, upper = Inf, 
   lower_is_strict = FALSE, upper_is_strict = FALSE)
 {                                                     
-  msg <- sprintf("%s are not all in range.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all in range.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_in_range, 
@@ -89,7 +89,7 @@ assert_all_are_in_range <- function(x, lower = -Inf, upper = Inf,
 assert_any_are_in_range <- function(x, lower = -Inf, upper = Inf, 
   lower_is_strict = FALSE, upper_is_strict = FALSE)
 {                                                     
-  msg <- sprintf("%s are all out of range.", get_name_in_parent(x))
+  msg <- gettextf("%s are all out of range.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_in_range, 
@@ -106,7 +106,7 @@ assert_any_are_in_range <- function(x, lower = -Inf, upper = Inf,
 #' @export
 assert_all_are_in_right_open_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are not all in range.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all in range.", get_name_in_parent(x))
   assert_engine(x, is_in_right_open_range, msg, lower = lower, upper = upper)  
 }
 
@@ -114,7 +114,7 @@ assert_all_are_in_right_open_range <- function(x, lower = -Inf, upper = Inf)
 #' @export
 assert_any_are_in_right_open_range <- function(x, lower = -Inf, upper = Inf)
 {                                                     
-  msg <- sprintf("%s are all out of range.", get_name_in_parent(x))
+  msg <- gettextf("%s are all out of range.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_in_right_open_range, 
@@ -129,7 +129,7 @@ assert_any_are_in_right_open_range <- function(x, lower = -Inf, upper = Inf)
 #' @export
 assert_all_are_negative <- function(x)
 {                                                                
-  msg <- sprintf("%s are not all negative.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all negative.", get_name_in_parent(x))
   assert_engine(x, is_negative, msg)
 }
 
@@ -137,7 +137,7 @@ assert_all_are_negative <- function(x)
 #' @export
 assert_any_are_negative <- function(x)
 {                                                        
-  msg <- sprintf("%s are all not negative.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not negative.", get_name_in_parent(x))
   assert_engine(x, is_negative, msg, what = "any")
 }
 
@@ -145,7 +145,7 @@ assert_any_are_negative <- function(x)
 #' @export
 assert_all_are_non_negative <- function(x)
 {                                                       
-  msg <- sprintf("%s are not all non-negative.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all non-negative.", get_name_in_parent(x))
   assert_engine(x, is_non_negative, msg)
 }
 
@@ -153,7 +153,7 @@ assert_all_are_non_negative <- function(x)
 #' @export
 assert_any_are_non_negative <- function(x)
 {                                                      
-  msg <- sprintf("%s are all not non-negative.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not non-negative.", get_name_in_parent(x))
   assert_engine(x, is_non_negative, msg, what = "any")
 }
 
@@ -161,7 +161,7 @@ assert_any_are_non_negative <- function(x)
 #' @export
 assert_all_are_non_positive <- function(x)
 {                                                       
-  msg <- sprintf("%s contains positive values.", get_name_in_parent(x))
+  msg <- gettextf("%s contains positive values.", get_name_in_parent(x))
   assert_engine(x, is_non_positive, msg)
 }
 
@@ -169,7 +169,7 @@ assert_all_are_non_positive <- function(x)
 #' @export
 assert_any_are_non_positive <- function(x)
 {                                                      
-  msg <- sprintf("%s are all positive.", get_name_in_parent(x))
+  msg <- gettextf("%s are all positive.", get_name_in_parent(x))
   assert_engine(x, is_non_positive, msg, what = "any")
 }
 
@@ -178,7 +178,7 @@ assert_any_are_non_positive <- function(x)
 assert_all_are_percentages <- function(x, lower_is_strict = FALSE, 
   upper_is_strict = FALSE)
 {                                                       
-  msg <- sprintf("%s are not all percentages.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all percentages.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_percentage, 
@@ -193,7 +193,7 @@ assert_all_are_percentages <- function(x, lower_is_strict = FALSE,
 assert_any_are_percentages <- function(x, lower_is_strict = FALSE, 
   upper_is_strict = FALSE)
 {                                                       
-  msg <- sprintf("%s are all not percentages.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not percentages.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_percentage, 
@@ -208,7 +208,7 @@ assert_any_are_percentages <- function(x, lower_is_strict = FALSE,
 #' @export
 assert_all_are_positive <- function(x)
 {                                                       
-  msg <- sprintf("%s contains non-positive values.", get_name_in_parent(x))
+  msg <- gettextf("%s contains non-positive values.", get_name_in_parent(x))
   assert_engine(x, is_positive, msg)
 }
 
@@ -216,7 +216,7 @@ assert_all_are_positive <- function(x)
 #' @export
 assert_any_are_positive <- function(x)
 {                                                      
-  msg <- sprintf("%s are all non-positive.", get_name_in_parent(x))
+  msg <- gettextf("%s are all non-positive.", get_name_in_parent(x))
   assert_engine(x, is_positive, msg, what = "any")
 }
 
@@ -225,7 +225,7 @@ assert_any_are_positive <- function(x)
 assert_all_are_proportions <- function(x, lower_is_strict = FALSE, 
   upper_is_strict = FALSE)
 {                                                       
-  msg <- sprintf("%s are not all proportions.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all proportions.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_proportion, 
@@ -240,7 +240,7 @@ assert_all_are_proportions <- function(x, lower_is_strict = FALSE,
 assert_any_are_proportions <- function(x, lower_is_strict = FALSE, 
   upper_is_strict = FALSE)
 {                                                       
-  msg <- sprintf("%s are all not proportions.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not proportions.", get_name_in_parent(x))
   assert_engine(
     x, 
     is_proportion, 
