@@ -2,7 +2,7 @@
 #' @export
 assert_all_are_uk_car_licences <- function(x)
 {                                                     
-  msg <- sprintf("%s are not all UK car licence plates.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all UK car licence plates.", get_name_in_parent(x))
   assert_engine(x, is_uk_car_licence, msg)        
 }
 
@@ -10,7 +10,7 @@ assert_all_are_uk_car_licences <- function(x)
 #' @export
 assert_any_are_uk_car_licences <- function(x)
 {                                                     
-  msg <- sprintf("%s are all not UK car licence plates.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not UK car licence plates.", get_name_in_parent(x))
   assert_engine(x, is_uk_car_licence, msg, what = "any")        
 }
 
@@ -26,7 +26,7 @@ assert_any_are_uk_car_licenses <- assert_any_are_uk_car_licences
 #' @export
 assert_all_are_uk_national_insurance_numbers <- function(x)
 {                                                     
-  msg <- sprintf(
+  msg <- gettextf(
     "%s are not all UK national insurance numbers.", 
     get_name_in_parent(x)
   )
@@ -37,7 +37,7 @@ assert_all_are_uk_national_insurance_numbers <- function(x)
 #' @export
 assert_any_are_uk_national_insurance_numbers <- function(x)
 {                                                     
-  msg <- sprintf(
+  msg <- gettextf(
     "%s are all not UK national insurance numbers.", 
     get_name_in_parent(x)
   )
@@ -48,7 +48,7 @@ assert_any_are_uk_national_insurance_numbers <- function(x)
 #' @export
 assert_all_are_uk_postcodes <- function(x)
 {                                                     
-  msg <- sprintf("%s are not all UK postcodes.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all UK postcodes.", get_name_in_parent(x))
   assert_engine(x, is_uk_postcode, msg)        
 }
 
@@ -56,7 +56,7 @@ assert_all_are_uk_postcodes <- function(x)
 #' @export
 assert_any_are_uk_postcodes <- function(x)
 {                                                     
-  msg <- sprintf("%s are all not UK postcodes.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not UK postcodes.", get_name_in_parent(x))
   assert_engine(x, is_uk_postcode, msg, what = "any")        
 }
 
@@ -64,7 +64,7 @@ assert_any_are_uk_postcodes <- function(x)
 #' @export
 assert_all_are_uk_telephone_numbers <- function(x)
 {                                                     
-  msg <- sprintf("%s are not all UK telephone numbers.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all UK telephone numbers.", get_name_in_parent(x))
   assert_engine(x, is_uk_telephone_number, msg)        
 }
 
@@ -72,6 +72,6 @@ assert_all_are_uk_telephone_numbers <- function(x)
 #' @export
 assert_any_are_uk_telephone_numbers <- function(x)
 {                                                     
-  msg <- sprintf("%s are all not UK telephone numbers.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not UK telephone numbers.", get_name_in_parent(x))
   assert_engine(x, is_uk_telephone_number, msg, what = "any")        
 }
