@@ -2,7 +2,7 @@
 #' @export
 assert_all_are_us_telephone_numbers <- function(x)
 {                                                     
-  msg <- sprintf("%s are not all US telephone numbers.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all US telephone numbers.", get_name_in_parent(x))
   assert_engine(x, is_us_telephone_number, msg)        
 }
 
@@ -10,7 +10,7 @@ assert_all_are_us_telephone_numbers <- function(x)
 #' @export
 assert_any_are_us_telephone_numbers <- function(x)
 {                                                     
-  msg <- sprintf("%s are all not US telephone numbers.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not US telephone numbers.", get_name_in_parent(x))
   assert_engine(x, is_us_telephone_number, msg, what = "any")        
 }
 
@@ -19,7 +19,7 @@ assert_any_are_us_telephone_numbers <- function(x)
 #' @export
 assert_all_are_us_zip_codes <- function(x)
 {                                                     
-  msg <- sprintf("%s are not all US zip codes.", get_name_in_parent(x))
+  msg <- gettextf("%s are not all US zip codes.", get_name_in_parent(x))
   assert_engine(x, is_us_zip_code, msg)        
 }
 
@@ -27,6 +27,6 @@ assert_all_are_us_zip_codes <- function(x)
 #' @export
 assert_any_are_us_zip_codes <- function(x)
 {                                                     
-  msg <- sprintf("%s are all not US zip codes.", get_name_in_parent(x))
+  msg <- gettextf("%s are all not US zip codes.", get_name_in_parent(x))
   assert_engine(x, is_us_zip_code, msg, what = "any")        
 }
