@@ -542,11 +542,11 @@ is_relistable <- function(x, .xname = get_name_in_parent(x))
 #' \code{is_S4} returns \code{FALSE}.
 #' @seealso \code{\link[base]{isS4}}.
 #' @examples
-#' assert_is_S4(getClass("MethodDefinition"))
+#' assert_is_s4(getClass("MethodDefinition"))
 #' #These examples should fail.
-#' dont_stop(assert_is_S4(1:10))
+#' dont_stop(assert_is_s4(1:10))
 #' @export
-is_S4 <- function(x, .xname = get_name_in_parent(x))
+is_s4 <- function(x, .xname = get_name_in_parent(x))
 {
   if(!isS4(x))
   {
@@ -555,6 +555,14 @@ is_S4 <- function(x, .xname = get_name_in_parent(x))
   TRUE
 } 
 
+#' @rdname is_s4
+#' @export
+is_S4 <- function(x, .xname = get_name_in_parent(x))
+{
+  .Deprecated("is_s4")
+  is_s4(x, .xname)
+}
+
 #' @rdname is_function
 #' @export
 is_stepfun <- function(x, .xname = get_name_in_parent(x))
